Learn R Programming

SemNeT (version 2.0.0)

cn: Community Network Estimation

Description

Estimates a semantic network using the Community Network method described in Goni et al. (2011)

Usage

cn(data, window = 2, alpha = 0.05, enrich = FALSE)

CN(data, window = 2, alpha = 0.05, enrich = FALSE)

Value

Returns an undirected semantic network

Arguments

data

Matrix or data frame. A preprocessed verbal fluency matrix where rows are participants and columns are the order of their verbal fluency responses. Content may be the raw word responses or an ordered numeric response matrix (see responses_to_binary())

window

Numeric. Size of window to look for co-occurrences in. Defaults to 2

alpha

Numeric. Significance value. Defaults to .05

enrich

Boolean. Should the network be enriched by connecting all nodes within their respective modules? Defaults to FALSE

Author

Alexander Christensen <alexpaulchristensen@gmail.com>

References

Goni, J., Arrondo, G., Sepulcre, J., Martincorena, I., de Mendizabal, N. V., Corominas-Murtra, B., ... & Villoslada, P. (2011). The semantic organization of the animal category: Evidence from semantic verbal fluency and network theory. Cognitive Processing, 12, 183-196.

Examples

Run this code
# Get data
data <- open.clean

# Organize group data
group <- open.group
low <- data[which(group == "Low"), ]
high <- data[which(group == "High"), ]

if (FALSE) {
# Compute networks
low_net <- cn(low)
high_net <- cn(high)
}

Run the code above in your browser using DataLab