Learn R Programming

SemNeT (version 2.0.0)

finalize: Finalize a Response Matrix

Description

Finalizes a binary response matrix by keeping only responses given by at least a minimum number of participants

Usage

finalize(data, minimum_cases = 2)

Value

A binary response matrix containing only responses given by at least minimum_cases participants

Arguments

data

Matrix or data frame. A binary response matrix (participants x responses)

minimum_cases

Numeric. Minimum number of participants required to have given a response for that response to be kept. Defaults to 2

Author

Alexander Christensen <alexpaulchristensen@gmail.com>

Examples

Run this code
# Obtain binary data
bin <- open.binary

# Finalize
final <- finalize(bin)

Run the code above in your browser using DataLab