powered by
Finalizes a binary response matrix by keeping only responses given by at least a minimum number of participants
finalize(data, minimum_cases = 2)
A binary response matrix containing only responses given by at least minimum_cases participants
minimum_cases
Matrix or data frame. A binary response matrix (participants x responses)
Numeric. Minimum number of participants required to have given a response for that response to be kept. Defaults to 2
2
Alexander Christensen <alexpaulchristensen@gmail.com>
# Obtain binary data bin <- open.binary # Finalize final <- finalize(bin)
Run the code above in your browser using DataLab